AddPubspecAsset class final

Appends an asset path to the flutter.assets list in pubspec.yaml.

Example

AddPubspecAsset(assetPath: 'assets/config.json')
Inheritance

Constructors

AddPubspecAsset({required String assetPath})
Creates an AddPubspecAsset operation.
const

Properties

assetPath String
The asset path to append (relative to the project root).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe() String
Returns a human-readable dry-run line for this operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited