ArgumentSpec class

Positional argument specification parsed out of a signature.

Constructors

ArgumentSpec({required String name, bool isOptional = false, bool isVariadic = false, String? defaultValue, String? description})
const

Properties

defaultValue String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
isOptional bool
final
isVariadic bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited