ArgvInput class

Parses List<String> argv typical of CLI invocation.

Implemented types

Constructors

ArgvInput(ArgResults _results, {CommandSignature? signature})
ArgvInput.parse(ArgParser parser, List<String> args, {CommandSignature? signature})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbosity int
Argument verbosity level parsed from -v, -vv, -vvv, -vvvv.
no setteroverride

Methods

argument(Object indexOrName) String?
Get a positional argument by 0-based index OR by name.
override
hasOption(String name) bool
Check whether the option was provided explicitly (vs defaulted).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
option(String name) → dynamic
Get a named option / flag value (returns null if absent).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited