CdpPortProbe typedef

CdpPortProbe = Future<bool> Function(int port)

Probes whether port is available for binding on loopback. Returns true when the port is free, false when already in use.

Implementation

typedef CdpPortProbe = Future<bool> Function(int port);