CopyFile class final

Copies a file from sourcePath to targetPath.

Both paths are relative to the project root.

Example

CopyFile(sourcePath: 'assets/template.dart', targetPath: 'lib/out.dart')
Inheritance

Constructors

CopyFile({required String sourcePath, required String targetPath})
Creates a CopyFile operation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourcePath String
Source path relative to the project root.
final
targetPath String
Destination path relative to the project root.
final

Methods

describe() String
Returns a human-readable dry-run line for this operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited