DeleteFile class final

Deletes the file at targetPath if it exists.

Example

DeleteFile(targetPath: 'lib/old/legacy.dart')
Inheritance

Constructors

DeleteFile({required String targetPath})
Creates a DeleteFile operation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetPath String
Path of the file to delete, relative to the project root.
final

Methods

describe() String
Returns a human-readable dry-run line for this operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited