GradleConfig class

Gradle plugins + dependencies block (lives under native.android.gradle).

Constructors

GradleConfig({required List<GradlePluginSpec> plugins, required List<GradleDepSpec> deps})
Creates a GradleConfig.
const
GradleConfig.fromYaml(YamlMap m)
Parses the gradle: sub-map.
factory

Properties

deps List<GradleDepSpec>
Gradle dependencies (scope + Maven notation).
final
hashCode int
The hash code for this object.
no setterinherited
plugins List<GradlePluginSpec>
Gradle plugins (id + optional version).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited