GradleDepSpec class

One Gradle dependency entry: {scope, notation}.

Constructors

GradleDepSpec({required String scope, required String notation})
Creates a GradleDepSpec.
const
GradleDepSpec.fromYaml(YamlMap m)
Parses one Gradle dependency entry.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
notation String
Maven coordinate notation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
Gradle scope (implementation, classpath, ...).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited