GradlePluginSpec class

One Gradle plugin entry: {id, version?}.

Constructors

GradlePluginSpec({required String id, String? version})
Creates a GradlePluginSpec.
const
GradlePluginSpec.fromYaml(YamlMap m)
Parses one plugin entry.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Gradle plugin id (e.g. com.google.gms.google-services).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
Optional version constraint.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited