InjectAndroidMetaData class final

Adds a <meta-data> element inside <application> in AndroidManifest.xml.

Example

InjectAndroidMetaData(
  name: 'com.google.firebase.messaging.default_icon',
  value: '@mipmap/ic_launcher',
)
Inheritance

Constructors

InjectAndroidMetaData({required String name, required String value})
Creates an InjectAndroidMetaData operation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The android:name attribute value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The android:value attribute value.
final

Methods

describe() String
Returns a human-readable dry-run line for this operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited