InjectIntoWebHead class final

Injects raw HTML content before the closing </head> tag in web/index.html.

Example

InjectIntoWebHead(content: '<script src="app.js"></script>')
Inheritance

Constructors

InjectIntoWebHead({required String content})
Creates an InjectIntoWebHead operation.
const

Properties

content String
Raw HTML content to inject before </head>.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe() String
Returns a human-readable dry-run line for this operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited