InjectPodfileLine class final

Appends a line to the Podfile target block for platform.

platform should be 'ios' or 'macos'.

Example

InjectPodfileLine(platform: 'ios', line: "pod 'Firebase/Messaging'")
Inheritance

Constructors

InjectPodfileLine({required String platform, required String line})
Creates an InjectPodfileLine operation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
line String
The Podfile line to append inside the target block.
final
platform String
Target platform: 'ios' or 'macos'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe() String
Returns a human-readable dry-run line for this operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited