boot property
What boot context the dispatcher must establish before calling handle. See CommandBoot for the V1 taxonomy (none, connected).
Implementation
@override
CommandBoot get boot => CommandBoot.none;
What boot context the dispatcher must establish before calling handle. See CommandBoot for the V1 taxonomy (none, connected).
@override
CommandBoot get boot => CommandBoot.none;