OptionSpec class

Option / flag specification parsed out of a signature.

Constructors

OptionSpec({required String name, bool isFlag = false, String? defaultValue, String? description})
const

Properties

defaultValue String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
isFlag bool
true when the option is a boolean switch with no value (e.g. --force).
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited