PodfileConfig class

Podfile sub-block (under native.ios.podfile or native.macos.podfile).

Constructors

PodfileConfig({String? platformVersion, required List<String> pods})
Creates a PodfileConfig.
const
PodfileConfig.fromYaml(YamlMap m)
Parses the podfile: sub-map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
platformVersion String?
Optional platform :ios (or :osx) minimum version. Informational in v1: no chain method consumes it yet.
final
pods List<String>
Pod declarations to append to target 'Runner'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited