RemoveDependency class final

Removes a dependency from pubspec.yaml (from either dependencies or dev_dependencies).

Example

RemoveDependency(name: 'legacy_pkg')
Inheritance

Constructors

RemoveDependency({required String name})
Creates a RemoveDependency operation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The package name to remove.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe() String
Returns a human-readable dry-run line for this operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited