Success class final

All staged operations applied; the install record was persisted.

Inheritance

Constructors

Success({required int opCount, required String recordPath})
Creates a Success result.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
opCount int
Number of operations applied.
final
recordPath String
Absolute path of the persisted .artisan/installed/<plugin>.json record.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe() String
Returns a single-line human-readable summary of the result.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited