TinkerCaster typedef

TinkerCaster = String? Function(Object? value)

Returns a formatted string representation of value, or null to defer to the next caster in the chain.

Implementation

typedef TinkerCaster = String? Function(Object? value);