WebConfig class

Web native configuration sub-section.

Constructors

WebConfig({required List<String> headScripts, required List<Map<String, String>> metaTags})
Creates a WebConfig.
const
WebConfig.fromYaml(YamlMap m)
Parses the native.web: sub-map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
headScripts List<String>
HTML snippets to inject before </head>.
final
metaTags List<Map<String, String>>
<meta> attribute maps to add to web/index.html.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited