AddWebMetaTag class final
Adds a <meta> tag to web/index.html with the given attributes.
Example
AddWebMetaTag(attributes: {'name': 'viewport', 'content': 'width=device-width'})
- Inheritance
-
- Object
- InstallOperation
- AddWebMetaTag
Constructors
-
AddWebMetaTag({required Map<
String, String> attributes}) -
Creates an AddWebMetaTag operation.
const
Properties
-
attributes
→ Map<
String, String> -
Attribute map for the
<meta>element (e.g.name,content,charset).final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
describe(
) → String -
Returns a human-readable dry-run line for this operation.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited