AndroidConfig class
Android native configuration sub-section.
Constructors
-
AndroidConfig({required List<
String> permissions, required Map<String, String> metaData, GradleConfig? gradle}) -
Creates an AndroidConfig.
const
- AndroidConfig.fromYaml(YamlMap m)
-
Parses the
native.android:sub-map.factory
Properties
- gradle → GradleConfig?
-
Optional Gradle plugins + dependencies block.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metaData
→ Map<
String, String> -
<meta-data>entries (name → value).final -
permissions
→ List<
String> -
Permissions to add under
<uses-permission>.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited