Conflict class final
Pre-flight conflict detector flagged one or more user-modified files and
the caller did not pass force: true.
- Inheritance
-
- Object
- TransactionResult
- Conflict
Constructors
-
Conflict({required List<
FileConflict> conflicts}) -
Creates a Conflict result.
const
Properties
-
conflicts
→ List<
FileConflict> -
The conflict list returned by the detector.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
describe(
) → String -
Returns a single-line human-readable summary of the result.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited