InjectPodfileLine class final
Appends a line to the Podfile target block for platform.
platform should be 'ios' or 'macos'.
Example
InjectPodfileLine(platform: 'ios', line: "pod 'Firebase/Messaging'")
- Inheritance
-
- Object
- InstallOperation
- InjectPodfileLine
Constructors
- InjectPodfileLine({required String platform, required String line})
-
Creates an InjectPodfileLine operation.
const
Properties
Methods
-
describe(
) → String -
Returns a human-readable dry-run line for this operation.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited